-------------------------------------------------------------------------------
-- MrTrader 
--
-- Suite of tools for the avid crafter.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

function MRTUIUtils_FilterButton_SetType(button, type, text, isLast)
	local normalText = _G[button:GetName().."NormalText"];
	local normalTexture = _G[button:GetName().."NormalTexture"];
	local line = _G[button:GetName().."Lines"];
	
	line:Hide();
	if ( type == "class" ) then
		button:SetText(text);
		normalText:SetPoint("LEFT", button, "LEFT", 4, 0);
		normalTexture:SetAlpha(1.0);	
	elseif ( type == "subclass" ) then
		button:SetText(HIGHLIGHT_FONT_COLOR_CODE..text..FONT_COLOR_CODE_CLOSE);
		normalText:SetPoint("LEFT", button, "LEFT", 12, 0);
		normalTexture:SetAlpha(0.4);
	end
	button.type = type; 
end

-----
-- Methods to let addons get at the state of 'have materials' for the tradeskill window.
-----
function MRTUIUtils_GetTradeSkillOnlyShowMakeable()
	return MRTSkillFrameAvailableFilterCheckButton:GetChecked();
end

function MRTUIUtils_SetTradeSkillOnlyShowMakeable(value)
	MRTSkillFrameAvailableFilterCheckButton:SetChecked(value);
	TradeSkillOnlyShowMakeable(MRTSkillFrameAvailableFilterCheckButton:GetChecked());
end

----
-- Methods to let addons clear out the state of the filter selection (for scanning), and then restore it.
----
function MRTUIUtils_PushFilterSelection()
	MRTSkillWindow.savedFilterSelection = MRTSkillWindow.filterSelection;
	MRTSkillWindow.savedFilterCategory = MRTSkillWindow.filterCategory;
	MRTSkillWindow.savedShowOnlyMakeable = MRTUIUtils_GetTradeSkillOnlyShowMakeable();
	MRTSkillWindow.filterSelection = nil;
	MRTSkillWindow.filterCategory = nil;
	MRTUIUtils_SetTradeSkillOnlyShowMakeable(false);
	
	MRTSkillWindow:PopulateFilterTree();	
	MRTSkillWindow:Update();
end

function MRTUIUtils_PopFilterSelection()
	MRTUIUtils_SetTradeSkillOnlyShowMakeable(MRTSkillWindow.savedOnlyMakeable);
	MRTSkillWindow.filterSelection = MRTSkillWindow.savedFilterSelection;
	MRTSkillWindow.filterCategory = MRTSkillWindow.savedFilterCategory;
	
	MRTSkillWindow:PopulateFilterTree();	
	MRTSkillWindow:Update();
end

-----
-- Methods to let addons hook the skill buttons more easily
-----
local MRTOnShow = {};
local MRTOnHide = {};
local MRTOnWindowShow = {};
local MRTOnWindowUpdate = {};

function MRTUIUtils_RegisterSkillOnShow(handler)
	tinsert(MRTOnShow, handler);
end

function MRTUIUtils_RegisterSkillOnHide(handler)
	tinsert(MRTOnHide, handler);
end

function MRTUIUtils_RegisterWindowOnShow(handler)
	tinsert(MRTOnWindowShow, handler);
end

function MRTUIUtils_RegisterWindowOnUpdate(handler)
	tinsert(MRTOnWindowUpdate, handler);
end

function MRTUIUtils_SkillOnShow(skillButtonFrame)
	MRTUIUtils_CallFunctionList(MRTOnShow, skillButtonFrame);
end

function MRTUIUtils_SkillOnHide(skillButtonFrame)
	MRTUIUtils_CallFunctionList(MRTOnHide, skillButtonFrame);	
end

function MRTUIUtils_WindowOnShow(skillFrame)
	MRTUIUtils_CallFunctionList(MRTOnWindowShow, skillFrame);
end

function MRTUIUtils_CallFunctionList(list, self)
	local count = getn(list);
	for i=1,count do
		list[i](self);
	end	
end
